maxResponsiveDialogWidth property
The maximum width of the responsive dialog.
Defaults to 600 if not set.
This is used to limit the width of the responsive dialog.
Implementation
final double maxResponsiveDialogWidth;
The maximum width of the responsive dialog.
Defaults to 600 if not set.
This is used to limit the width of the responsive dialog.
final double maxResponsiveDialogWidth;