useInAppWebViewOnWeb property
Uses flutter_inappwebview for the web captcha surface when running on web.
Defaults to false to preserve the current HtmlElementView-based behavior.
Implementation
final bool useInAppWebViewOnWeb;
Uses flutter_inappwebview for the web captcha surface when running on web.
Defaults to false to preserve the current HtmlElementView-based behavior.
final bool useInAppWebViewOnWeb;