CaptchaType enum

Defines how the captcha widget should be displayed in the app.

Inheritance
Available extensions

Values

screen → const CaptchaType

Displays captcha in a full screen page with an AppBar.

dialog → const CaptchaType

Displays captcha inside a dialog box (popup overlay).

modalBottomSheet → const CaptchaType

Displays captcha inside a modal bottom sheet.

responsiveDialog → const CaptchaType

Displays captcha inside a responsive dialog.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CaptchaType>
A constant List of the values in this enum, in order of their declaration.