CaptchaParams class

Constructors

CaptchaParams({required CaptchaType mode, required dynamic onError(String error), required dynamic onSuccess(String token)})

Properties

hashCode int
The hash code for this object.
no setterinherited
mode CaptchaType
final
onError → dynamic Function(String error)
final
onSuccess → dynamic Function(String token)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited