ArCaptchaSectionHolder class

A platform-agnostic holder for rendering the captcha widget.

Depending on the platform (web or mobile), the exported implementation will switch between:

  • ArCaptchaMobileDialog (mobile)
  • ArCaptchaWebDialog (web)
  • a fallback Container (stub, should never be used).
Inheritance

Constructors

ArCaptchaSectionHolder({Key? key, required String htmlWidget, bool showLoadingOverlay = false, String? loadingText, bool useInAppWebViewOnWeb = false, required bool enableDebugLogging, double captchaHeight = 550, double captchaWidth = 550})
const

Properties

captchaHeight double
final
captchaWidth double
final
enableDebugLogging bool
final
hashCode int
The hash code for this object.
no setterinherited
htmlWidget String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingText String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLoadingOverlay bool
final
useInAppWebViewOnWeb bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ArCaptchaSectionHolder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited