CustomModalBottomSheet class

A reusable wrapper around showCupertinoModalBottomSheet that displays the captcha (or any widget) inside a Cupertino-style modal bottom sheet.

The modal’s drag and dismiss behavior can be configured globally using ArCaptchaController.enableModalDrag and ArCaptchaController.isModalDismissible.

Constructors

CustomModalBottomSheet({dynamic actionOnCloseModal(dynamic)?, required Widget bottomSheetModal})
const

Properties

actionOnCloseModal → dynamic Function(dynamic)?
Optional callback invoked when the modal is closed.
final
bottomSheetModal → Widget
The widget to display inside the modal bottom sheet.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBottomSheet({required BuildContext context}) → void
Opens the bottom sheet using showCupertinoModalBottomSheet.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited