animationDuration top-level property

Duration animationDuration
getter/setter pair

A fully adaptive dialog system that dynamically switches between a centered dialog (desktop/tablet) and a modal bottom sheet (mobile).

This implementation is built on top of showGeneralDialog to allow maximum flexibility over layout, animation, and interaction behavior.


🚀 Usage:

ResponsiveDialog.show( showDialogParam: ShowDialogParameters( context: context, dialogChildWidget: Widget(...), barrierDismissible: true, backgroundColor: Colors.white, actionOnCloseModal: (value) { print('value $value'); }, ), );

Implementation

Duration animationDuration = const Duration(milliseconds: 250);